@@ -95,7 +95,7 @@ at your option, any later version of Perl 5 you may have available.
 =cut
 
 use 5.008;
-our $VERSION = '0.06';
+our $VERSION = '0.09';
 
 #use Data::Dumper;
 use Carp;
@@ -116,8 +116,9 @@ sub new{
     }
     my %args = @_;
     my ($can,$x,$y,$size,$colour) = @args{qw/canvas x y size colour/};
-    eval {$can->isa('Tk::Canvas');$can->Exists;};
-    croak "something is wrong with this 'canvas':<$can> $@" if $@;
+    eval {$can->isa('Tk::Canvas')};
+    croak "this is not a 'Canvas':<$can> $@" if $@;
+    unless ($can->Exists){croak "This Canvas does not Exist:<$can>"};
     my $text_id;
     my @center = map {ref($_)?$$_:$_} ($x,$y);
     $size ||= 10;
